==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiCore/QJsonParseError_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qjsondocument.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QJsonParseError(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QJsonParseError")
    QJsonParseError *_ptr = reinterpret_cast<QJsonParseError *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QJsonParseError_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QJsonParseError *__qt_this = new(__qtjambi_ptr) QJsonParseError();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QJsonParseError
void __qt_destruct_QJsonParseError(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QJsonParseError")
    reinterpret_cast<QJsonParseError*>(ptr)->~QJsonParseError();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QJsonParseError::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_initialize_1native__Lio_qt_core_QJsonParseError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJsonParseError::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QJsonParseError_0, sizeof(QJsonParseError), typeid(QJsonParseError), false, &deleter_QJsonParseError, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QJsonParseError::errorString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_errorString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QJsonParseError *__qt_this = QtJambiAPI::objectFromNativeId<QJsonParseError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QJsonParseError::errorString()const", __qt_this)
        QString __qt_return_value = __qt_this->errorString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_setError_1native_1cref_1QJsonParseError_1ParseError__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint error0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QJsonParseError *__qt_this = QtJambiAPI::objectFromNativeId<QJsonParseError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QJsonParseError::ParseError __qt_error0 = qtjambi_cast<QJsonParseError::ParseError>(__jni_env, error0);
        __qt_this->error = QJsonParseError::ParseError(__qt_error0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_error_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QJsonParseError *__qt_this = QtJambiAPI::objectFromNativeId<QJsonParseError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QJsonParseError::ParseError&  __qt_value = __qt_this->error;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_setOffset_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QJsonParseError *__qt_this = QtJambiAPI::objectFromNativeId<QJsonParseError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->offset = static_cast<int>(offset0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_offset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QJsonParseError *__qt_this = QtJambiAPI::objectFromNativeId<QJsonParseError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->offset;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QJsonParseError *__qt_this = QtJambiAPI::objectFromNativeId<QJsonParseError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QJsonParseError(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QJsonParseError>("QJsonParseError", "io/qt/core/QJsonParseError");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QJsonParseError, {
        ConstructorInfo(&__qt_construct_QJsonParseError_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QJsonParseError);
    registerMetaType<QJsonParseError>("QJsonParseError");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QJsonParseError::ParseError>("QJsonParseError::ParseError", "io/qt/core/QJsonParseError$ParseError");
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiCore/QJsonParseError_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qjsondocument.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QJsonParseError(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QJsonParseError")
    QJsonParseError *_ptr = reinterpret_cast<QJsonParseError *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QJsonParseError()
void __qt_construct_QJsonParseError(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QJsonParseError()")
    Q_UNUSED(__java_arguments)
    QJsonParseError *__qt_this = new(__qtjambi_ptr) QJsonParseError();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QJsonParseError::QJsonParseError()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_initialize_1native__Lio_qt_core_QJsonParseError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJsonParseError::QJsonParseError()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QJsonParseError, sizeof(QJsonParseError), typeid(QJsonParseError), 0, false, &deleter_QJsonParseError, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QJsonParseError(QJsonParseError)
void __qt_construct_QJsonParseError_cref_QJsonParseError(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QJsonParseError(QJsonParseError)")
    jobject other0 = __java_arguments[0].l;
    const QJsonParseError& __qt_other0 = qtjambi_cast<const QJsonParseError&>(__jni_env, other0);
    QJsonParseError *__qt_this = new(__qtjambi_ptr) QJsonParseError(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QJsonParseError::QJsonParseError(QJsonParseError)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_initialize_1native__Lio_qt_core_QJsonParseError_2Lio_qt_core_QJsonParseError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJsonParseError::QJsonParseError(QJsonParseError)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QJsonParseError_cref_QJsonParseError, sizeof(QJsonParseError), typeid(QJsonParseError), 0, false, &deleter_QJsonParseError, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QJsonParseError{int,QJsonParseError::ParseError}
void __qt_construct_QJsonParseError_int_QJsonParseError_ParseError(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QJsonParseError{int,QJsonParseError::ParseError}")
    jint offset0 = __java_arguments[0].i;
    Q_UNUSED(offset0)
    jobject error1 = __java_arguments[1].l;
    QJsonParseError::ParseError __qt_error1 = qtjambi_cast<QJsonParseError::ParseError>(__jni_env, error1);
    QJsonParseError *__qt_this = new(__qtjambi_ptr) QJsonParseError{static_cast<int>(offset0), QJsonParseError::ParseError(__qt_error1)};
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QJsonParseError::QJsonParseError{int,QJsonParseError::ParseError}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_initialize_1native__Lio_qt_core_QJsonParseError_2ILio_qt_core_QJsonParseError_00024ParseError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint offset0,
 jobject error1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJsonParseError::QJsonParseError{int,QJsonParseError::ParseError}")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].i = offset0;
        arguments[1].l = error1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QJsonParseError_int_QJsonParseError_ParseError, sizeof(QJsonParseError), typeid(QJsonParseError), 0, false, &deleter_QJsonParseError, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QJsonParseError
void __qt_destruct_QJsonParseError(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QJsonParseError")
    reinterpret_cast<QJsonParseError*>(ptr)->~QJsonParseError();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QJsonParseError::errorString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_errorString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QJsonParseError *__qt_this = QtJambiAPI::objectFromNativeId<QJsonParseError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QJsonParseError::errorString()const", __this_nativeId)
        QString __qt_return_value = __qt_this->errorString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_setError_1native_1cref_1QJsonParseError_1ParseError__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint error0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QJsonParseError *__qt_this = QtJambiAPI::objectFromNativeId<QJsonParseError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QJsonParseError::ParseError __qt_error0 = qtjambi_cast<QJsonParseError::ParseError>(__jni_env, error0);
        __qt_this->error = QJsonParseError::ParseError(__qt_error0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_error_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QJsonParseError *__qt_this = QtJambiAPI::objectFromNativeId<QJsonParseError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QJsonParseError::ParseError&  __qt_value = __qt_this->error;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_setOffset_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QJsonParseError *__qt_this = QtJambiAPI::objectFromNativeId<QJsonParseError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->offset = static_cast<int>(offset0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_offset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QJsonParseError *__qt_this = QtJambiAPI::objectFromNativeId<QJsonParseError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->offset;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QJsonParseError_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QJsonParseError *__qt_this = QtJambiAPI::objectFromNativeId<QJsonParseError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QJsonParseError(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QJsonParseError>("QJsonParseError", "io/qt/core/QJsonParseError");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QJsonParseError, {
        ConstructorInfo(&__qt_construct_QJsonParseError, nullptr)
       ,ConstructorInfo(&__qt_construct_QJsonParseError_cref_QJsonParseError, "Lio/qt/core/QJsonParseError;")
       ,ConstructorInfo(&__qt_construct_QJsonParseError_int_QJsonParseError_ParseError, "ILio/qt/core/QJsonParseError$ParseError;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QJsonParseError);
    registerMetaType<QJsonParseError>("QJsonParseError");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QJsonParseError::ParseError>("QJsonParseError::ParseError", "io/qt/core/QJsonParseError$ParseError");
// END: enums and flags
}
